Module models

Module models 

Request and response types for the Zart HTTP API.

Structs

ErrorResponse
Body for error responses.
ExecutionDetailResponse
Response for GET /zart/admin/v1/executions/:id/detail.
ExecutionResponse
JSON representation of a durable execution record.
ListQuery
Query parameters for GET /api/v1/executions.
PauseRequest
Body for POST /zart/admin/v1/pause.
PauseRuleResponse
Response for a single pause rule.
PotentiallyStaleDepResponse
A preserved step that may have a stale dependency on a rerun step.
RerunRequest
Body for POST /zart/admin/v1/executions/:id/rerun.
RerunResponse
Body returned for a successful rerun.
RestartRequest
Body for POST /zart/admin/v1/executions/:id/restart.
RestartResponse
Body returned for a successful restart.
ResumeResponse
Response for a resume operation.
RetryStepRequest
Body for POST /zart/admin/v1/executions/:id/retry-step.
RetryStepResponse
Body returned for a successful retry-step.
RunRecordResponse
A single run record returned from the runs list.
StartExecutionRequest
Body for POST /api/v1/executions.
StartExecutionResponse
Body returned for a successful start.
StatsResponse
Response for GET /api/v1/stats.
StepAttemptResponse
A single step attempt in the detail response.
StepDetailResponse
A step with its attempt history.
WaitQuery
Query parameters for GET /api/v1/executions/:id/wait.