pub struct ApiServer { /* private fields */ }Expand description
The Zart API server.
Wraps an Axum router and exposes durable execution management over HTTP.
Implementations
Sourceimpl ApiServer
impl ApiServer
Sourcepub fn new(addr: impl Into<String>, durable: Arc<dyn DurableApi>) -> Self
pub fn new(addr: impl Into<String>, durable: Arc<dyn DurableApi>) -> Self
Create a new API server bound to addr.
Sourcepub fn with_cancellation(
addr: impl Into<String>,
durable: Arc<dyn DurableApi>,
cancellation: CancellationToken,
) -> Self
pub fn with_cancellation( addr: impl Into<String>, durable: Arc<dyn DurableApi>, cancellation: CancellationToken, ) -> Self
Create a new API server with a cancellation token for graceful shutdown.